==> ZendFramework-1.10.6.tbz: share/ZendFramework/externals/dojo/dojo/cldr/nls/de/gregorian.js <==
({
	"months-format-narrow": [
		"J", 
		"F", 
		"M", 
		"A", 
		"M", 
		"J", 
		"J", 
		"A", 
		"S", 
		"O", 
		"N", 
		"D"
	], 
	"quarters-standAlone-narrow": [
		"1", 
		"2", 
		"3", 
		"4"
	], 
	"field-weekday": "Wochentag", 
	"dateFormatItem-yyQQQQ": "QQQQ yy", 
	"dateFormatItem-yQQQ": "QQQ y", 
	"dateFormatItem-yMEd": "EEE, yyyy-M-d", 
	"dateFormatItem-MMMEd": "E d. MMM", 
	"eraNarrow": [
		"v. Chr.", 
		"n. Chr."
	], 
	"dateFormat-long": "d. MMMM y", 
	"months-format-wide": [
		"Januar", 
		"Februar", 
		"März", 
		"April", 
		"Mai", 
		"Juni", 
		"Juli", 
		"August", 
		"September", 
		"Oktober", 
		"November", 
		"Dezember"
	], 
	"dateTimeFormat-medium": "{1} {0}", 
	"dateFormatItem-EEEd": "d. EEE", 
	"dateFormat-full": "EEEE, d. MMMM y", 
	"dateFormatItem-Md": "d.M.", 
	"dateFormatItem-yyMMdd": "dd.MM.yy", 
	"field-era": "Epoche", 
	"dateFormatItem-yM": "yyyy-M", 
	"months-standAlone-wide": [
		"Januar", 
		"Februar", 
		"März", 
		"April", 
		"Mai", 
		"Juni", 
		"Juli", 
		"August", 
		"September", 
		"Oktober", 
		"November", 
		"Dezember"
	], 
	"timeFormat-short": "HH:mm", 
	"quarters-format-wide": [
		"1. Quartal", 
		"2. Quartal", 
		"3. Quartal", 
		"4. Quartal"
	], 
	"timeFormat-long": "HH:mm:ss z", 
	"field-year": "Jahr", 
	"dateFormatItem-yMMM": "MMM y", 
	"dateFormatItem-yQ": "Q yyyy", 
	"dateFormatItem-yyyyMMMM": "MMMM y", 
	"field-hour": "Stunde", 
	"dateFormatItem-MMdd": "dd.MM.", 
	"months-format-abbr": [
		"Jan", 
		"Feb", 
		"Mär", 
		"Apr", 
		"Mai", 
		"Jun", 
		"Jul", 
		"Aug", 
		"Sep", 
		"Okt", 
		"Nov", 
		"Dez"
	], 
	"dateFormatItem-yyQ": "Q yy", 
	"timeFormat-full": "HH:mm:ss zzzz", 
	"am": "vorm.", 
	"dateFormatItem-H": "H", 
	"months-standAlone-abbr": [
		"Jan", 
		"Feb", 
		"Mär", 
		"Apr", 
		"Mai", 
		"Jun", 
		"Jul", 
		"Aug", 
		"Sep", 
		"Okt", 
		"Nov", 
		"Dez"
	], 
	"quarters-format-abbr": [
		"Q1", 
		"Q2", 
		"Q3", 
		"Q4"
	], 
	"quarters-standAlone-wide": [
		"1. Quartal", 
		"2. Quartal", 
		"3. Quartal", 
		"4. Quartal"
	], 
	"dateFormatItem-HHmmss": "HH:mm:ss", 
	"dateFormatItem-M": "L", 
	"days-standAlone-wide": [
		"Sonntag", 
		"Montag", 
		"Dienstag", 
		"Mittwoch", 
		"Donnerstag", 
		"Freitag", 
		"Samstag"
	], 
	"dateFormatItem-MMMMd": "d. MMMM", 
	"dateFormatItem-yyMMM": "MMM yy", 
	"timeFormat-medium": "HH:mm:ss", 
	"dateFormatItem-Hm": "H:mm", 
	"eraAbbr": [
		"v. Chr.", 
		"n. Chr."
	], 
	"field-minute": "Minute", 
	"field-dayperiod": "Tageshälfte", 
	"days-standAlone-abbr": [
		"So.", 
		"Mo.", 
		"Di.", 
		"Mi.", 
		"Do.", 
		"Fr.", 
		"Sa."
	], 
	"dateFormatItem-d": "d", 
	"dateFormatItem-ms": "mm:ss", 
	"dateTimeFormat-long": "{1} {0}", 
	"dateFormatItem-MMMd": "d. MMM", 
	"dateFormatItem-MEd": "E, d.M.", 
	"dateTimeFormat-full": "{1} {0}", 
	"dateFormatItem-yMMMM": "MMMM y", 
	"field-day": "Tag", 
	"days-format-wide": [
		"Sonntag", 
		"Montag", 
		"Dienstag", 
		"Mittwoch", 
		"Donnerstag", 
		"Freitag", 
		"Samstag"
	], 
	"field-zone": "Zone", 
	"dateFormatItem-y": "y", 
	"months-standAlone-narrow": [
		"J", 
		"F", 
		"M", 
		"A", 
		"M", 
		"J", 
		"J", 
		"A", 
		"S", 
		"O", 
		"N", 
		"D"
	], 
	"dateFormatItem-yyMM": "MM.yy", 
	"days-format-abbr": [
		"So.", 
		"Mo.", 
		"Di.", 
		"Mi.", 
		"Do.", 
		"Fr.", 
		"Sa."
	], 
	"eraNames": [
		"v. Chr.", 
		"n. Chr."
	], 
	"days-format-narrow": [
		"S", 
		"M", 
		"D", 
		"M", 
		"D", 
		"F", 
		"S"
	], 
	"field-month": "Monat", 
	"days-standAlone-narrow": [
		"S", 
		"M", 
		"D", 
		"M", 
		"D", 
		"F", 
		"S"
	], 
	"dateFormatItem-MMM": "LLL", 
	"dateFormatItem-HHmm": "HH:mm", 
	"pm": "nachm.", 
	"dateFormatItem-MMMMEd": "E d. MMMM", 
	"dateFormatItem-MMMMdd": "dd. MMMM", 
	"dateFormat-short": "dd.MM.yy", 
	"dateFormatItem-MMd": "d.MM.", 
	"field-second": "Sekunde", 
	"dateFormatItem-yMMMEd": "EEE, d. MMM y", 
	"dateFormatItem-Ed": "E d.", 
	"field-week": "Woche", 
	"dateFormat-medium": "dd.MM.yyyy", 
	"dateFormatItem-mmss": "mm:ss", 
	"dateTimeFormat-short": "{1} {0}", 
	"dateFormatItem-yyyy": "y"
})

==> ZendFramework-1.11.11.tbz: share/ZendFramework/externals/dojo/dojo/cldr/nls/de/gregorian.js <==
({
	"months-format-narrow": [
		"J", 
		"F", 
		"M", 
		"A", 
		"M", 
		"J", 
		"J", 
		"A", 
		"S", 
		"O", 
		"N", 
		"D"
	], 
	"field-weekday": "Wochentag", 
	"dateFormatItem-yyQQQQ": "QQQQ yy", 
	"dateFormatItem-yQQQ": "QQQ y", 
	"dateFormatItem-yMEd": "EEE, d.M.y", 
	"dateFormatItem-MMMEd": "E d. MMM", 
	"eraNarrow": [
		"v. Chr.", 
		"n. Chr."
	], 
	"dayPeriods-format-wide-earlyMorning": "morgens", 
	"dayPeriods-format-wide-morning": "vormittags", 
	"dateFormat-long": "d. MMMM y", 
	"months-format-wide": [
		"Januar", 
		"Februar", 
		"März", 
		"April", 
		"Mai", 
		"Juni", 
		"Juli", 
		"August", 
		"September", 
		"Oktober", 
		"November", 
		"Dezember"
	], 
	"dayPeriods-format-wide-evening": "abends", 
	"dateFormatItem-EEEd": "d. EEE", 
	"dayPeriods-format-wide-pm": "nachm.", 
	"dateFormat-full": "EEEE, d. MMMM y", 
	"dateFormatItem-Md": "d.M.", 
	"dateFormatItem-yyMMdd": "dd.MM.yy", 
	"dayPeriods-format-wide-noon": "Mittag", 
	"field-era": "Epoche", 
	"dateFormatItem-yM": "M.y", 
	"months-standAlone-wide": [
		"Januar", 
		"Februar", 
		"März", 
		"April", 
		"Mai", 
		"Juni", 
		"Juli", 
		"August", 
		"September", 
		"Oktober", 
		"November", 
		"Dezember"
	], 
	"timeFormat-short": "HH:mm", 
	"quarters-format-wide": [
		"1. Quartal", 
		"2. Quartal", 
		"3. Quartal", 
		"4. Quartal"
	], 
	"timeFormat-long": "HH:mm:ss z", 
	"field-year": "Jahr", 
	"dateFormatItem-yMMM": "MMM y", 
	"dateFormatItem-yQ": "Q y", 
	"dateFormatItem-yyyyMMMM": "MMMM y", 
	"dateFormatItem-MMdd": "dd.MM.", 
	"field-hour": "Stunde", 
	"months-format-abbr": [
		"Jan", 
		"Feb", 
		"Mär", 
		"Apr", 
		"Mai", 
		"Jun", 
		"Jul", 
		"Aug", 
		"Sep", 
		"Okt", 
		"Nov", 
		"Dez"
	], 
	"dateFormatItem-yyQ": "Q yy", 
	"timeFormat-full": "HH:mm:ss zzzz", 
	"field-day-relative+0": "heute", 
	"field-day-relative+1": "morgen", 
	"field-day-relative+2": "übermorgen", 
	"dateFormatItem-H": "HH", 
	"field-day-relative+3": "überübermorgen", 
	"months-standAlone-abbr": [
		"Jan", 
		"Feb", 
		"Mär", 
		"Apr", 
		"Mai", 
		"Jun", 
		"Jul", 
		"Aug", 
		"Sep", 
		"Okt", 
		"Nov", 
		"Dez"
	], 
	"quarters-format-abbr": [
		"Q1", 
		"Q2", 
		"Q3", 
		"Q4"
	], 
	"quarters-standAlone-wide": [
		"1. Quartal", 
		"2. Quartal", 
		"3. Quartal", 
		"4. Quartal"
	], 
	"dateFormatItem-M": "L", 
	"days-standAlone-wide": [
		"Sonntag", 
		"Montag", 
		"Dienstag", 
		"Mittwoch", 
		"Donnerstag", 
		"Freitag", 
		"Samstag"
	], 
	"dateFormatItem-yyMMM": "MMM yy", 
	"timeFormat-medium": "HH:mm:ss", 
	"dateFormatItem-Hm": "HH:mm", 
	"eraAbbr": [
		"v. Chr.", 
		"n. Chr."
	], 
	"field-minute": "Minute", 
	"field-dayperiod": "Tageshälfte", 
	"dayPeriods-format-wide-night": "nachts", 
	"days-standAlone-abbr": [
		"So.", 
		"Mo.", 
		"Di.", 
		"Mi.", 
		"Do.", 
		"Fr.", 
		"Sa."
	], 
	"dateFormatItem-d": "d", 
	"dateFormatItem-ms": "mm:ss", 
	"field-day-relative+-1": "gestern", 
	"field-day-relative+-2": "vorgestern", 
	"field-day-relative+-3": "vorvorgestern", 
	"dateFormatItem-MMMd": "d. MMM", 
	"dateFormatItem-MEd": "E, d.M.", 
	"field-day": "Tag", 
	"days-format-wide": [
		"Sonntag", 
		"Montag", 
		"Dienstag", 
		"Mittwoch", 
		"Donnerstag", 
		"Freitag", 
		"Samstag"
	], 
	"field-zone": "Zone", 
	"dateFormatItem-y": "y", 
	"months-standAlone-narrow": [
		"J", 
		"F", 
		"M", 
		"A", 
		"M", 
		"J", 
		"J", 
		"A", 
		"S", 
		"O", 
		"N", 
		"D"
	], 
	"dateFormatItem-yyMM": "MM.yy", 
	"days-format-abbr": [
		"So.", 
		"Mo.", 
		"Di.", 
		"Mi.", 
		"Do.", 
		"Fr.", 
		"Sa."
	], 
	"eraNames": [
		"v. Chr.", 
		"n. Chr."
	], 
	"days-format-narrow": [
		"S", 
		"M", 
		"D", 
		"M", 
		"D", 
		"F", 
		"S"
	], 
	"field-month": "Monat", 
	"days-standAlone-narrow": [
		"S", 
		"M", 
		"D", 
		"M", 
		"D", 
		"F", 
		"S"
	], 
	"dateFormatItem-MMM": "LLL", 
	"dayPeriods-format-wide-am": "vorm.", 
	"dateFormatItem-MMMMdd": "dd. MMMM", 
	"dateFormat-short": "dd.MM.yy", 
	"dateFormatItem-MMd": "d.MM.", 
	"dayPeriods-format-wide-afternoon": "nachmittags", 
	"field-second": "Sekunde", 
	"dateFormatItem-yMMMEd": "EEE, d. MMM y", 
	"dateFormatItem-Ed": "E d.", 
	"field-week": "Woche", 
	"dateFormat-medium": "dd.MM.yyyy", 
	"dateFormatItem-Hms": "HH:mm:ss", 
	"dateFormatItem-yyyy": "y"
})
